## 2.7.0.6 (2023-02-22)

Update `Unused` parameters in `stubs/` (#9704)

* Update _Unused TypeAlias

* Update `object | None` params

* Replace unused `object` parameters with `Unused` alias

## 2.7.0.5 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 2.7.0.4 (2023-02-15)

Use `typing_extensions.Self` instead of `_typeshed.Self` (#9702)

## 2.7.0.3 (2023-02-07)

Complete `python-crontab` (#9306)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 2.7.0.2 (2023-02-07)

Bump mypy to 1.0 (#9684)

## 2.7.0.1 (2022-12-24)

crontab: upstream did some py2 cleanup (#9406)

Fixes #9405

## 2.7.0.0 (2022-12-23)

crontab: improve types, update to 2.7 (#9392)

https://gitlab.com/doctormo/python-crontab/-/blob/v2.7.0/crontab.py

Closes #9391

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

## 2.6.0.2 (2022-11-16)

Always use `bool` and `Literal` for Python compat code (#9213)

## 2.6.0.1 (2022-10-20)

Mark `python-crontab` as completed (#8938)

## 2.6.0.0 (2022-10-20)

Add stubs for python-cronlog (#8917)

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>
Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

